==> gitlab_15.8.5%2Bds1.orig.tar.xz: gitlab-foss-v15.8.5/spec/graphql/types/query_type_spec.rb <==
# frozen_string_literal: true

require 'spec_helper'

RSpec.describe GitlabSchema.types['Query'] do
  it 'is called Query' do
    expect(described_class.graphql_name).to eq('Query')
  end

  it 'has the expected fields' do
    expected_fields = [
      :board_list,
      :ci_application_settings,
      :ci_config,
      :ci_variables,
      :container_repository,
      :current_user,
      :design_management,
      :echo,
      :gitpod_enabled,
      :group,
      :issue,
      :issues,
      :jobs,
      :merge_request,
      :metadata,
      :milestone,
      :namespace,
      :package,
      :project,
      :projects,
      :query_complexity,
      :runner,
      :runner_platforms,
      :runner_setup,
      :runners,
      :snippets,
      :timelogs,
      :todo,
      :topics,
      :usage_trends_measurements,
      :user,
      :users,
      :work_item
    ]

    expect(described_class).to have_graphql_fields(*expected_fields).at_least
  end

  describe 'namespace field' do
    subject { described_class.fields['namespace'] }

    it 'finds namespaces by full path' do
      is_expected.to have_graphql_arguments(:full_path)
      is_expected.to have_graphql_type(Types::NamespaceType)
      is_expected.to have_graphql_resolver(Resolvers::NamespaceResolver)
    end
  end

  describe 'project field' do
    subject { described_class.fields['project'] }

    it 'finds projects by full path' do
      is_expected.to have_graphql_arguments(:full_path)
      is_expected.to have_graphql_type(Types::ProjectType)
      is_expected.to have_graphql_resolver(Resolvers::ProjectResolver)
    end
  end

  describe 'metadata field' do
    subject { described_class.fields['metadata'] }

    it 'returns metadata' do
      is_expected.to have_graphql_type(Types::MetadataType)
      is_expected.to have_graphql_resolver(Resolvers::MetadataResolver)
    end
  end

  describe 'issue field' do
    subject { described_class.fields['issue'] }

    it "finds an issue by it's gid" do
      is_expected.to have_graphql_arguments(:id)
      is_expected.to have_graphql_type(Types::IssueType)
    end
  end

  describe 'merge_request field' do
    subject { described_class.fields['mergeRequest'] }

    it "finds a merge_request by it's gid" do
      is_expected.to have_graphql_arguments(:id)
      is_expected.to have_graphql_type(Types::MergeRequestType)
    end
  end

  describe 'usage_trends_measurements field' do
    subject { described_class.fields['usageTrendsMeasurements'] }

    it 'returns usage trends measurements' do
      is_expected.to have_graphql_type(Types::Admin::Analytics::UsageTrends::MeasurementType.connection_type)
    end
  end

  describe 'runner field' do
    subject { described_class.fields['runner'] }

    it { is_expected.to have_graphql_type(Types::Ci::RunnerType) }
  end

  describe 'runners field' do
    subject { described_class.fields['runners'] }

    it { is_expected.to have_graphql_type(Types::Ci::RunnerType.connection_type) }
  end

  describe 'runner_platforms field' do
    subject { described_class.fields['runnerPlatforms'] }

    it 'returns runner platforms' do
      is_expected.to have_graphql_type(Types::Ci::RunnerPlatformType.connection_type)
    end
  end

  describe 'runner_setup field' do
    subject { described_class.fields['runnerSetup'] }

    it 'returns runner setup instructions' do
      is_expected.to have_graphql_type(Types::Ci::RunnerSetupType)
    end
  end

  describe 'container_repository field' do
    subject { described_class.fields['containerRepository'] }

    it { is_expected.to have_graphql_type(Types::ContainerRepositoryDetailsType) }
  end

  describe 'package field' do
    subject { described_class.fields['package'] }

    it { is_expected.to have_graphql_type(Types::Packages::PackageDetailsType) }
  end

  describe 'timelogs field' do
    subject { described_class.fields['timelogs'] }

    it 'returns timelogs' do
      is_expected.to have_graphql_arguments(:startDate, :endDate, :startTime, :endTime, :username, :projectId, :groupId, :after, :before, :first, :last, :sort)
      is_expected.to have_graphql_type(Types::TimelogType.connection_type)
      is_expected.to have_graphql_resolver(Resolvers::TimelogResolver)
    end
  end

  describe 'boardList field' do
    subject { described_class.fields['boardList'] }

    it 'finds a board list by its gid' do
      is_expected.to have_graphql_arguments(:id, :issue_filters)
      is_expected.to have_graphql_type(Types::BoardListType)
      is_expected.to have_graphql_resolver(Resolvers::BoardListResolver)
    end
  end
end

==> gitlab_16.0.7%2Bds1.orig.tar.xz: gitlab-foss-v16.0.7/spec/graphql/types/query_type_spec.rb <==
# frozen_string_literal: true

require 'spec_helper'

RSpec.describe GitlabSchema.types['Query'], feature_category: :shared do
  include_context 'with FOSS query type fields'

  it 'is called Query' do
    expect(described_class.graphql_name).to eq('Query')
  end

  it 'has the expected fields' do
    expect(described_class).to have_graphql_fields(*expected_foss_fields).at_least
  end

  describe 'namespace field' do
    subject { described_class.fields['namespace'] }

    it 'finds namespaces by full path' do
      is_expected.to have_graphql_arguments(:full_path)
      is_expected.to have_graphql_type(Types::NamespaceType)
      is_expected.to have_graphql_resolver(Resolvers::NamespaceResolver)
    end
  end

  describe 'project field' do
    subject { described_class.fields['project'] }

    it 'finds projects by full path' do
      is_expected.to have_graphql_arguments(:full_path)
      is_expected.to have_graphql_type(Types::ProjectType)
      is_expected.to have_graphql_resolver(Resolvers::ProjectResolver)
    end
  end

  describe 'metadata field' do
    subject { described_class.fields['metadata'] }

    it 'returns metadata' do
      is_expected.to have_graphql_type(Types::MetadataType)
      is_expected.to have_graphql_resolver(Resolvers::MetadataResolver)
    end
  end

  describe 'issue field' do
    subject { described_class.fields['issue'] }

    it "finds an issue by it's gid" do
      is_expected.to have_graphql_arguments(:id)
      is_expected.to have_graphql_type(Types::IssueType)
    end
  end

  describe 'merge_request field' do
    subject { described_class.fields['mergeRequest'] }

    it "finds a merge_request by it's gid" do
      is_expected.to have_graphql_arguments(:id)
      is_expected.to have_graphql_type(Types::MergeRequestType)
    end
  end

  describe 'usage_trends_measurements field' do
    subject { described_class.fields['usageTrendsMeasurements'] }

    it 'returns usage trends measurements' do
      is_expected.to have_graphql_type(Types::Admin::Analytics::UsageTrends::MeasurementType.connection_type)
    end
  end

  describe 'runner field' do
    subject { described_class.fields['runner'] }

    it { is_expected.to have_graphql_type(Types::Ci::RunnerType) }
  end

  describe 'runners field' do
    subject { described_class.fields['runners'] }

    it { is_expected.to have_graphql_type(Types::Ci::RunnerType.connection_type) }
  end

  describe 'runner_platforms field' do
    subject { described_class.fields['runnerPlatforms'] }

    it 'returns runner platforms' do
      is_expected.to have_graphql_type(Types::Ci::RunnerPlatformType.connection_type)
    end
  end

  describe 'runner_setup field' do
    subject { described_class.fields['runnerSetup'] }

    it 'returns runner setup instructions' do
      is_expected.to have_graphql_type(Types::Ci::RunnerSetupType)
    end
  end

  describe 'container_repository field' do
    subject { described_class.fields['containerRepository'] }

    it { is_expected.to have_graphql_type(Types::ContainerRepositoryDetailsType) }
  end

  describe 'package field' do
    subject { described_class.fields['package'] }

    it { is_expected.to have_graphql_type(Types::Packages::PackageDetailsType) }
  end

  describe 'timelogs field' do
    subject { described_class.fields['timelogs'] }

    it 'returns timelogs' do
      is_expected.to have_graphql_arguments(:startDate, :endDate, :startTime, :endTime, :username, :projectId, :groupId, :after, :before, :first, :last, :sort)
      is_expected.to have_graphql_type(Types::TimelogType.connection_type)
      is_expected.to have_graphql_resolver(Resolvers::TimelogResolver)
    end
  end

  describe 'boardList field' do
    subject { described_class.fields['boardList'] }

    it 'finds a board list by its gid' do
      is_expected.to have_graphql_arguments(:id, :issue_filters)
      is_expected.to have_graphql_type(Types::BoardListType)
      is_expected.to have_graphql_resolver(Resolvers::BoardListResolver)
    end
  end
end
